@@ -68,7 +68,7 @@ class YouTube(VideoExtractor):
          'audio_encoding': 'AAC', 'audio_bitrate': '24'},
     ]
 
-    def decipher(js, s):
+    def s_to_sig(js, s):
         # Examples:
         # - https://www.youtube.com/yts/jsbin/player-da_DK-vflWlK-zq/base.js
         # - https://www.youtube.com/yts/jsbin/player-vflvABTsY/da_DK/base.js
@@ -204,13 +204,22 @@ class YouTube(VideoExtractor):
                 video_page = get_content('https://www.youtube.com/watch?v=%s' % self.vid)
                 try:
                     ytplayer_config = json.loads(re.search('ytplayer.config\s*=\s*([^\n]+?});', video_page).group(1))
-                    self.html5player = 'https://www.youtube.com' + ytplayer_config['assets']['js']
+
                     # Workaround: get_video_info returns bad s. Why?
                     if 'url_encoded_fmt_stream_map' not in ytplayer_config['args']:
                         stream_list = json.loads(ytplayer_config['args']['player_response'])['streamingData']['formats']
                     else:
                         stream_list = ytplayer_config['args']['url_encoded_fmt_stream_map'].split(',')
                     #stream_list = ytplayer_config['args']['adaptive_fmts'].split(',')
+
+                    if 'assets' in ytplayer_config:
+                        self.html5player = 'https://www.youtube.com' + ytplayer_config['assets']['js']
+                    elif re.search('([^"]*/base\.js)"', video_page):
+                        self.html5player = 'https://www.youtube.com' + re.search('([^"]*/base\.js)"', video_page).group(1)
+                        self.html5player = self.html5player.replace('\/', '/') # unescape URL
+                    else:
+                        self.html5player = None
+
                 except:
                     if 'url_encoded_fmt_stream_map' not in video_info:
                         stream_list = json.loads(video_info['player_response'][0])['streamingData']['formats']
@@ -481,13 +490,13 @@ class YouTube(VideoExtractor):
                 if stream['type'].startswith('audio/mp4'):
                     dash_mp4_a_url = stream['url']
                     if 's' in stream:
-                        sig = self.__class__.decipher(self.js, stream['s'])
+                        sig = self.__class__.s_to_sig(self.js, stream['s'])
                         dash_mp4_a_url += '&sig={}'.format(sig)
                     dash_mp4_a_size = stream['clen']
                 elif stream['type'].startswith('audio/webm'):
                     dash_webm_a_url = stream['url']
                     if 's' in stream:
-                        sig = self.__class__.decipher(self.js, stream['s'])
+                        sig = self.__class__.s_to_sig(self.js, stream['s'])
                         dash_webm_a_url += '&sig={}'.format(sig)
                     dash_webm_a_size = stream['clen']
             for stream in streams: # video
@@ -496,7 +505,7 @@ class YouTube(VideoExtractor):
                         mimeType = 'video/mp4'
                         dash_url = stream['url']
                         if 's' in stream:
-                            sig = self.__class__.decipher(self.js, stream['s'])
+                            sig = self.__class__.s_to_sig(self.js, stream['s'])
                             dash_url += '&sig={}'.format(sig)
                         dash_size = stream['clen']
                         itag = stream['itag']
@@ -515,7 +524,7 @@ class YouTube(VideoExtractor):
                         mimeType = 'video/webm'
                         dash_url = stream['url']
                         if 's' in stream:
-                            sig = self.__class__.decipher(self.js, stream['s'])
+                            sig = self.__class__.s_to_sig(self.js, stream['s'])
                             dash_url += '&sig={}'.format(sig)
                         dash_size = stream['clen']
                         itag = stream['itag']
@@ -564,7 +573,7 @@ class YouTube(VideoExtractor):
                 if not hasattr(self, 'js'):
                     self.js = get_content(self.html5player)
                 s = self.streams[stream_id]['s']
-                sig = self.__class__.decipher(self.js, s)
+                sig = self.__class__.s_to_sig(self.js, s)
                 src += '&sig={}'.format(sig)
 
             self.streams[stream_id]['src'] = [src]
